@@ -3,7 +3,7 @@
 ### Add SpatialDataFrame Response Case
 
 sre <- function (Response = NULL, Explanatory = NULL, NewData = NULL, Quant = 0.025, return_extremcond=FALSE){
-
+  
   # 1. Checking of input arguments validity
   args <- .check.params.sre(Response, Explanatory, NewData, Quant)
   
@@ -13,6 +13,7 @@ sre <- function (Response = NULL, Explanatory = NULL, NewData = NULL, Quant = 0.
   Quant <- args$Quant
   rm("args")
   
+  
   # 2. Determining suitables conditions and make the projection
   lout <- list()
   if(is.data.frame(Response) | is.matrix(Response)){
@@ -32,10 +33,11 @@ sre <- function (Response = NULL, Explanatory = NULL, NewData = NULL, Quant = 0.
     nb.resp <- nlayers(Response)
     resp.names <- names(Response)
     for(j in 1:nb.resp){
-      occ.pts <- raster:::subset(Response,j)
-      occ.pts[occ.pts != 1] <- NA
-      extrem.cond <- quantile(raster:::mask(Explanatory, occ.pts), probs = c(0 + Quant, 1 - Quant), na.rm = TRUE)
-      
+      occ.pts <- raster::subset(Response,j, drop=T)
+      x.ooc.pts <- Which(occ.pts != 1, cells=TRUE, na.rm=T)
+      occ.pts[x.ooc.pts] <- rep(NA, length(x.ooc.pts))
+      extrem.cond <- quantile(raster::mask(Explanatory, occ.pts), probs = c(0 + Quant, 1 - Quant), na.rm = TRUE)
+            
       if(!return_extremcond)
         lout[[j]] <- .sre.projection(NewData, extrem.cond)
     }
@@ -50,16 +52,20 @@ sre <- function (Response = NULL, Explanatory = NULL, NewData = NULL, Quant = 0.
         extrem.cond <- t(apply(as.data.frame(Explanatory[occ.pts,]), 2, 
                            quantile, probs = c(0 + Quant, 1 - Quant), na.rm = TRUE))
       } else { if(inherits(Explanatory, 'Raster')){
-        maskTmp <- raster:::subset(Explanatory,1)
-        maskTmp <- reclassify(maskTmp, c(-Inf,Inf,NA))
+        maskTmp <- raster::subset(Explanatory,1, drop=T)
+#         maskTmp <- reclassify(maskTmp, c(-Inf,Inf,NA))
+        maskTmp[] <- NA
         maskTmp[cellFromXY(maskTmp, coordinates(Response)[occ.pts,])] <- 1
-        extrem.cond <- quantile(raster:::mask(Explanatory, maskTmp), probs = c(0 + Quant, 1 - Quant), na.rm = TRUE)
+#         cat("\n*** sum(!is.na(maskTmp[])=",sum(!is.na(maskTmp[])))
+        
+        
+        extrem.cond <- quantile(raster::mask(Explanatory, maskTmp), probs = c(0 + Quant, 1 - Quant), na.rm = TRUE)      
       } else { if(inherits(Explanatory, 'SpatialPoints')){
         ## May be good to check corespondances of Response and Explanatory variables
         extrem.cond <- t(apply(as.data.frame(Explanatory[occ.pts,]), 2, 
                    quantile, probs = c(0 + Quant, 1 - Quant), na.rm = TRUE))
       } else { stop("Unsuported case!") } } }
-      
+       
       if(!return_extremcond)
         lout[[j]] <- .sre.projection(NewData, extrem.cond)
     }
@@ -77,7 +83,7 @@ sre <- function (Response = NULL, Explanatory = NULL, NewData = NULL, Quant = 0.
     if(inherits(NewData, 'Raster')){
       lout <- stack(lout)
       if(nlayers(lout)==1){
-        lout <- raster:::subset(lout,1,drop=TRUE)
+        lout <- raster::subset(lout,1,drop=TRUE)
       }
       names(lout) <- resp.names
     }
@@ -146,7 +152,7 @@ sre <- function (Response = NULL, Explanatory = NULL, NewData = NULL, Quant = 0.
       if(sum(!(names.expl.vars %in% names(NewData))) > 0 ){
         stop("Explanatory variables names differs in the 2 dataset given")
       }
-      NewData <- raster:::subset(NewData, names.expl.vars)
+      NewData <- raster::subset(NewData, names.expl.vars)
       if(nlayers(NewData) != nb.expl.vars ){
         stop("Incompatible number of variables in NewData objects")
       }
@@ -163,6 +169,7 @@ sre <- function (Response = NULL, Explanatory = NULL, NewData = NULL, Quant = 0.
 # -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-= #
       
 .sre.projection <- function(NewData, ExtremCond){
+  
   if(is.data.frame(NewData)|is.matrix(NewData)){
     out <- rep(1,nrow(NewData))
     for(j in 1:ncol(NewData)){
@@ -171,11 +178,11 @@ sre <- function (Response = NULL, Explanatory = NULL, NewData = NULL, Quant = 0.
   }
   
   if(inherits(NewData, "Raster")){
-    out <- reclassify(raster:::subset(NewData,1,drop=TRUE), c(-Inf, Inf, 1))
+    out <- reclassify(raster::subset(NewData,1,drop=TRUE), c(-Inf, Inf, 1))
     for(j in 1:nlayers(NewData)){
-      out <- out * ( raster:::subset(NewData,j,drop=TRUE) >= ExtremCond[j,1] ) * ( raster:::subset(NewData,j,drop=TRUE) <= ExtremCond[j,2] )
+      out <- out * ( raster::subset(NewData,j,drop=TRUE) >= ExtremCond[j,1] ) * ( raster::subset(NewData,j,drop=TRUE) <= ExtremCond[j,2] )
     }
-    out <- raster:::subset(out,1,drop=TRUE)
+    out <- raster::subset(out,1,drop=TRUE)
   }
 
   return(out)
